aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Target/X86/X86Relocations.h
diff options
context:
space:
mode:
authorEvan Cheng <evan.cheng@apple.com>2006-12-05 04:01:03 +0000
committerEvan Cheng <evan.cheng@apple.com>2006-12-05 04:01:03 +0000
commit19f2ffce4598c4c70f32eed7c6740b43185200b1 (patch)
tree3296988ab06147d942cb990a8f2e8c6dd6d811dc /lib/Target/X86/X86Relocations.h
parentd9ff60b955022954101700f867dcf315ba7d818d (diff)
downloadexternal_llvm-19f2ffce4598c4c70f32eed7c6740b43185200b1.zip
external_llvm-19f2ffce4598c4c70f32eed7c6740b43185200b1.tar.gz
external_llvm-19f2ffce4598c4c70f32eed7c6740b43185200b1.tar.bz2
- Fix X86-64 JIT by temporarily disabling code that treats GV address as 32-bit
immediate in small code model. The JIT cannot ensure GV's are placed in the lower 4G. - Some preliminary support for large code model. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@32215 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/X86/X86Relocations.h')
-rw-r--r--lib/Target/X86/X86Relocations.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/Target/X86/X86Relocations.h b/lib/Target/X86/X86Relocations.h
index bc1efabc..3dd2b24 100644
--- a/lib/Target/X86/X86Relocations.h
+++ b/lib/Target/X86/X86Relocations.h
@@ -23,9 +23,10 @@ namespace llvm {
// the value already in memory, after we adjust it for where the PC is.
reloc_pcrel_word = 0,
- // reloc_absolute_word - Absolute relocation, just add the relocated value
- // to the value already in memory.
- reloc_absolute_word = 1
+ // reloc_absolute_word, reloc_absolute_dword - Absolute relocation, just
+ // add the relocated value to the value already in memory.
+ reloc_absolute_word = 1,
+ reloc_absolute_dword = 2
};
}
}